@@ -53,6 +53,7 @@ import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.I2i;
 import static com.openexchange.java.Autoboxing.i2I;
 import java.io.IOException;
+import java.io.Serializable;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.rmi.RemoteException;
@@ -61,8 +62,8 @@ import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Set;
 import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
@@ -104,6 +105,8 @@ import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
+import com.openexchange.log.LogFactory;
+import com.openexchange.quota.Resource;
 import com.openexchange.tools.pipesnfilters.Filter;
 
 public class OXContext extends OXContextCommonImpl implements OXContextInterface {
@@ -125,6 +128,111 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
     }
 
+    @Override
+    public void changeQuota(final Context ctx, final String module, final long quotaValue, final Credentials credentials) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+        if (isEmpty(module)) {
+            throw new InvalidDataException("No valid module specified.");
+        }
+        {
+            final Resource[] resources = Resource.values();
+            boolean found = false;
+            for (int i = 0; !found && i < resources.length; i++) {
+                found = resources[i].getIdentifier().equalsIgnoreCase(module);
+            }
+            if (!found) {
+                throw new InvalidDataException("Unknown module: \"" + module + "\" (known modules: " + Arrays.toString(Resource.allIdentifiers()) + ")");
+            }
+        }
+
+        final Credentials auth = credentials == null ? new Credentials("", "") : credentials;
+
+        new BasicAuthenticator(context).doAuthentication(auth);
+
+        try {
+            setIdOrGetIDFromNameAndIdObject(null, ctx);
+        } catch (final NoSuchObjectException e) {
+            throw new NoSuchContextException(e);
+        }
+
+        final long quota;
+        if (quotaValue <= 0) {
+            quota = -1L;
+        } else {
+            // MySQL int(10) unsigned: the allowable range is from 0 to 4294967295
+            if (quotaValue > 4294967295L) {
+                throw new InvalidDataException("Quota value is out of range (allowable range is from 0 to 4294967295): " + quotaValue);
+            }
+            quota = quotaValue;
+        }
+
+        log.debug(ctx+" - "+module + " - " + quota);
+
+        try {
+            if (!tool.existsContext(ctx)) {
+                throw new NoSuchContextException();
+            }
+
+            callPluginMethod("changeQuota", ctx, module, Long.valueOf(quota), auth);
+
+            final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
+            oxcox.changeQuota(ctx, module, quota, auth);
+        } catch (final StorageException e) {
+            log.error(e.getMessage(), e);
+            throw e;
+        } catch (final NoSuchContextException e) {
+            log.error(e.getMessage(), e);
+            throw e;
+        }
+    }
+
+    @Override
+    public void changeCapabilities(Context ctx, Set<String> capsToAdd, Set<String> capsToRemove, Credentials credentials) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+        if ((null == capsToAdd || capsToAdd.isEmpty()) && (null == capsToRemove || capsToRemove.isEmpty())) {
+            throw new InvalidDataException("No capabilities specified.");
+        }
+
+        Credentials auth = credentials == null ? new Credentials("", "") : credentials;
+
+        new BasicAuthenticator(context).doAuthentication(auth);
+
+        try {
+            setIdOrGetIDFromNameAndIdObject(null, ctx);
+        } catch (NoSuchObjectException e) {
+            throw new NoSuchContextException(e);
+        }
+
+        log.debug(ctx+" - "+(null == capsToAdd ? "" : capsToAdd.toString())+" | "+(null == capsToRemove ? "" : capsToRemove.toString()));
+
+        try {
+            if (!tool.existsContext(ctx)) {
+                throw new NoSuchContextException();
+            }
+
+            callPluginMethod("changeCapabilities", ctx, capsToAdd, capsToRemove, auth);
+
+            final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
+            oxcox.changeCapabilities(ctx, capsToAdd, capsToRemove, auth);
+        } catch (final StorageException e) {
+            log.error(e.getMessage(), e);
+            throw e;
+        } catch (final NoSuchContextException e) {
+            log.error(e.getMessage(), e);
+            throw e;
+        }
+        final CacheService cacheService = AdminDaemon.getService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context, CacheService.class);
+        if (null != cacheService) {
+            try {
+                Cache jcs = cacheService.getCache("CapabilitiesContext");
+                final Serializable key = Integer.valueOf(ctx.getId().intValue());
+                jcs.remove(key);
+            } catch (final OXException e) {
+                log.error(e.getMessage(), e);
+            } finally {
+                AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
+            }
+        }
+    }
+
     @Override
     public void change(final Context ctx, Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
         auth = auth == null ? new Credentials("","") : auth;
@@ -302,7 +410,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             if (null != cacheService) {
                 try {
                     final Cache cache = cacheService.getCache("MailAccount");
-                    cache.invalidateGroup(Integer.toString(contextID));
+                    cache.clear();
                 } catch (final OXException e) {
                     log.error(e.getMessage(), e);
                 } finally {
@@ -1299,4 +1407,17 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
     public boolean checkExists(final Context ctx, Credentials auth) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException {
         return exists(ctx, auth);
     }
+
+    /** Check for an empty string */
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = Character.isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
+    }
 }
